@@ -23,7 +23,7 @@ from werkzeug.serving import run_with_reloader
 from .namespace import Namespace
 from .test_client import SocketIOTestClient
 
-__version__ = '2.9.6'
+__version__ = '3.0.0'
 
 
 class _SocketIOMiddleware(socketio.Middleware):
@@ -43,7 +43,7 @@ class _SocketIOMiddleware(socketio.Middleware):
                                                          start_response)
 
 
-class _ManagedSession(SessionMixin, dict):
+class _ManagedSession(dict, SessionMixin):
     """This class is used for user sessions that are managed by
     Flask-SocketIO. It is simple dict, expanded with the Flask session
     attributes."""
@@ -843,7 +843,8 @@ def disconnect(sid=None, namespace=None, silent=False):
         def receive_message(msg):
             if is_banned(session['username']):
                 disconnect()
-            # ...
+            else:
+                # ...
 
     :param sid: The session id of the client. If not provided, the client is
                 obtained from the request context.
